@@ -40,7 +40,7 @@ describe 'nova::placement' do
           :project_name        => 'service',
           :project_domain_name => 'default',
           :region_name         => 'RegionTwo',
-          :os_interface        => 'internal',
+          :valid_interfaces    => 'internal',
           :username            => 'placement2',
           :user_domain_name    => 'default',
           :auth_url            => 'https://127.0.0.1:5000/v3',
@@ -53,7 +53,7 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/project_name').with_value(params[:project_name])
         is_expected.to contain_nova_config('placement/project_domain_name').with_value(params[:project_domain_name])
         is_expected.to contain_nova_config('placement/region_name').with_value(params[:region_name])
-        is_expected.to contain_nova_config('placement/valid_interfaces').with_value(params[:os_interface])
+        is_expected.to contain_nova_config('placement/valid_interfaces').with_value(params[:valid_interfaces])
         is_expected.to contain_nova_config('placement/username').with_value(params[:username])
         is_expected.to contain_nova_config('placement/user_domain_name').with_value(params[:user_domain_name])
         is_expected.to contain_nova_config('placement/auth_url').with_value(params[:auth_url])
